# mrchead

[![License](https://img.shields.io/pypi/l/mrchead.svg?color=green)](https://github.com/alisterburt/mrchead/raw/master/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/mrchead.svg?color=green)](https://pypi.org/project/mrchead)
[![Python Version](https://img.shields.io/pypi/pyversions/mrchead.svg?color=green)](https://python.org)
[![CI](https://github.com/alisterburt/mrchead/workflows/ci/badge.svg)](https://github.com/alisterburt/mrchead/actions)
[![codecov](https://codecov.io/gh/alisterburt/mrchead/branch/master/graph/badge.svg)](https://codecov.io/gh/alisterburt/mrchead)

CLI tool for viewing mrc file headers
